//  Diffusion Client Library for iOS, tvOS and OS X / macOS
//
//  Copyright (c) 2018 - 2023 DiffusionData Ltd., All Rights Reserved.
//
//  Use is subject to licence terms.
//
//  NOTICE: All information contained herein is, and remains the
//  property of DiffusionData. The intellectual and technical
//  concepts contained herein are proprietary to DiffusionData and
//  may be covered by U.S. and Foreign Patents, patents in process, and
//  are protected by trade secret or copyright law.

#import <Foundation/Foundation.h>
#import <Diffusion/PTDiffusionStreamDelegate.h>

@class PTDiffusionSessionId;

NS_ASSUME_NONNULL_BEGIN

/**
 @brief Methods implemented by classes handling messaging responses from
 individual sessions.

 @see PTDiffusionMessagingFeature

 @since 6.1
 */
@protocol PTDiffusionSessionResponseStreamDelegate <PTDiffusionStreamDelegate>

/**
 Called when a session responds to a request with an error.

 @param stream The stream that received the response.

 @param error The error generated by the responding session.

 @param sessionId The id of the responding session.

 @since 6.1
 */
-(void)diffusionStream:(PTDiffusionStream *)stream
       didReceiveError:(NSError *)error
         fromSessionId:(PTDiffusionSessionId *)sessionId;

/**
 The stream closed prematurely.

 @param stream The stream that closed.

 @param error The reason why the stream closed.

 @note No further messages will be sent to the delegate for this stream.

 @since 5.6

 @deprecated since 6.6 this method is no longer called; in a future
 release, PTDiffusionSessionResponseStreamDelegate will no longer extend
 PTDiffusionStreamDelegate
 */
-(void)diffusionStream:(PTDiffusionStream *)stream
      didFailWithError:(NSError *)error
__deprecated_msg("Will be removed in a future release.");

/**
 The stream closed normally.

 @param stream The stream that closed.

 @note No further messages will be sent to the delegate for this stream.

 @since 5.6

 @deprecated since 6.6 this method is no longer called; in a future
 release, PTDiffusionSessionResponseStreamDelegate will no longer extend
 PTDiffusionStreamDelegate
 */
-(void)diffusionDidCloseStream:(PTDiffusionStream *)stream
__deprecated_msg("Will be removed in a future release.");


@end

NS_ASSUME_NONNULL_END
